/*
    This is an abstract base class. It defines the public interface
    that every shape should have. The definition of this public interface
    is separated from the implementation of the interface in the (concrete)
    subclasses.

    This class defines the computeArea() and computePerimeter() methods as
    abstract, since this class is too generic to know how area and perimeter
    should be calculated. Concrete subclasses have to provide an implementation
    for each of computeArea() and computePerimeter().
*/

public abstract class Shape
{
   private int x;
   private int y;

   public Shape(int x, int y)
   {
      this.x = x;
      this.y = y;
   }

   public int getX(){ return x; }

   public int getY(){ return y; }

   public abstract double computeArea();

   public abstract double computePerimeter();

   public String toString()
   {
      return "x = " + x + ", y = " + y;
   }

}//Shape
