/*
    The reason we want our Circle, Triangle, Rectangle, and Square
    classes all inheriting from a common Shape class is so that we
    have a uniform way of treating all objects of these different types.

    For example, below we store various Circle, Triangle, Rectangle, and
    Square objects together is a single array. If these objects did not
    share a common type, we would not be able to put them together is a
    single container. But since all of these objects are in fact Shape
    objects, they can be put together in a array of type Shape (though of
    course the objects are not really "in" the array).

    All shape objects share a common interface (declared in class Shape)
    so we can call computeArea() and computePerimeter() on every Shape
    object. Then polymorphism makes sure that the corect version of these
    methods get called on each individual object in the array.
*/

public class TestShapes
{
   public static void main(String[] args)
   {
      // A local reference variable for an array of type Shape.
      Shape[] myShape = new Shape[6];

      // "Fill" the array with different kinds of objects.
      // Notice that the array is uniformly made up of references
      // of type Shape, but the references point to objects of
      // several different types that all have Shape as a super class.
      myShape[0] = new Square(0, 0, 5);
      myShape[1] = new Circle(10, 5, 5);
      myShape[2] = new Rectangle(0, 0, 12, 2);
      myShape[3] = new Triangle(0, 0, 4);
      myShape[4] = new Circle(100, 100, 100);
      myShape[5] = new Square(5, 5, 9);

      for(int i = 0; i < myShape.length; i++)
      {
         // polymorphically call the computeArea() and
         // computePerimeter() methods on each object
         double area = myShape[i].computeArea();
         double perimeter = myShape[i].computePerimeter();
         System.out.println(myShape[i]
                            + ",\n\t area = " + area
                            + ", perimeter = " + perimeter );
      }

   }//main

}//TestShapes